STAC Python Library — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# STAC Python Library

Through this library you can verify the results obtained from the learning algorithms applying the statistic tests to the experiments, which, among other uses, support the decision making process (the election of the most suitable algorithm, for example).

# Normality tests

`shapiro`(x[, a, reta]) | Perform the Shapiro-Wilk test for normality.
`normaltest`(a[, axis]) | Tests whether a sample differs from a normal distribution.
`kstest`(rvs, cdf[, args, N, alternative, mode]) | Perform the Kolmogorov-Smirnov test for goodness of fit.

# Homoscedasticity tests

`levene`(*args, **kwds) | Perform Levene test for equal variances.

# Parametric two group comparison tests

`ttest_ind`(a, b[, axis, equal_var]) | Calculates the T-test for the means of TWO INDEPENDENT samples of scores.
`ttest_rel`(a, b[, axis]) | Calculates the T-test on TWO RELATED samples of scores, a and b.

# Non-parametric two group comparison tests

`wilcoxon`(x[, y, zero_method, correction]) | Calculate the Wilcoxon signed-rank test.
`mannwhitneyu`(x, y[, use_continuity]) | Computes the Mann-Whitney rank test on samples x and y.

`binomial_sign_test`(*args) | Performs a binomial sign test for two dependent samples.

# Parametric multiple comparison tests

## ANOVA tests

`anova_test`(*args) | Performs a 1-way ANOVA.
`anova_within_test`(*args) | Performs a 1-way ANOVA within cases.

## Post-hoc tests

`bonferroni_test`(pivots, n) | Performs a Bonferroni-Dunn post-hoc test using the pivot quantities obtained by an ANOVA test.

# Non-Parametric multiple comparison tests

## Ranking tests

`friedman_test`(*args) | Performs a Friedman ranking test.
`friedman_aligned_ranks_test`(*args) | Performs a Friedman aligned ranks ranking test.
`quade_test`(*args) | Performs a Quade ranking test.

## Post-hoc 1 vs all tests

`bonferroni_dunn_test`(ranks[, control]) | Performs a Bonferroni-Dunn post-hoc test using the pivot quantities obtained by a ranking test.
`holm_test`(ranks[, control]) | Performs a Holm post-hoc test using the pivot quantities obtained by a ranking test.
`finner_test`(ranks[, control]) | Performs a Finner post-hoc test using the pivot quantities obtained by a ranking test.
`hochberg_test`(ranks[, control]) | Performs a Hochberg post-hoc test using the pivot quantities obtained by a ranking test.
`li_test`(ranks[, control]) | Performs a Li post-hoc test using the pivot quantities obtained by a ranking test.

## Post-hoc all vs all tests

`nemenyi_multitest`(ranks) | Performs a Nemenyi post-hoc test using the pivot quantities obtained by a ranking test.
`holm_multitest`(ranks) | Performs a Holm post-hoc test using the pivot quantities obtained by a ranking test.
`finner_multitest`(ranks) | Performs a Finner post-hoc test using the pivot quantities obtained by a ranking test.
`hochberg_multitest`(ranks) | Performs a Hochberg post-hoc test using the pivot quantities obtained by a ranking test.
`shaffer_multitest`(ranks) | Performs a Shaffer post-hoc test using the pivot quantities obtained by a ranking test.

### Navigation

- index
- STAC Release Candidate documentation »